@@ -55,8 +55,8 @@ func NewDashboardAPIClient(ctx *config.RunContext) *DashboardAPIClient {
 	}
 }
 
-func (c *DashboardAPIClient) CreateAPIKey(name string, email string) (CreateAPIKeyResponse, error) {
-	d := map[string]string{"name": name, "email": email}
+func (c *DashboardAPIClient) CreateAPIKey(name string, email string, ciInterest bool) (CreateAPIKeyResponse, error) {
+	d := map[string]interface{}{"name": name, "email": email, "ci": ciInterest}
 	respBody, err := c.doRequest("POST", "/apiKeys?source=cli-register", d)
 	if err != nil {
 		return CreateAPIKeyResponse{}, err
@@ -75,7 +75,7 @@ func (c *DashboardAPIClient) AddRun(ctx *config.RunContext, projectContexts []*c
 	response := AddRunResponse{}
 
 	if !c.dashboardEnabled {
-		log.Debug("Skipping reporting project results since dashboard is not enabled")
+		log.Debug("Skipping sending project results to your dashboard since it is not enabled. Run 'infracost configure set enable_dashboard true' to enable it.")
 		return response, nil
 	}
 
