@@ -3,20 +3,24 @@ package azure
 import (
 	"strings"
 
-	"github.com/infracost/infracost/internal/schema"
 	"github.com/shopspring/decimal"
 	"github.com/tidwall/gjson"
+
+	"github.com/infracost/infracost/internal/schema"
 )
 
 func GetAzureRMApplicationInsightsWebRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:  "azurerm_application_insights_web_test",
 		RFunc: NewAzureRMApplicationInsightsWeb,
+		ReferenceAttributes: []string{
+			"resource_group_name",
+		},
 	}
 }
 
 func NewAzureRMApplicationInsightsWeb(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
-	region := lookupRegion(d, []string{})
+	region := lookupRegion(d, []string{"resource_group_name"})
 	costComponents := []*schema.CostComponent{}
 
 	if d.Get("kind").Type != gjson.Null {
