@@ -4,13 +4,13 @@ import "github.com/infracost/infracost/internal/schema"
 
 var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getArtifactRegistryRepositoryRegistryItem(),
-	GetBigqueryDatasetRegistryItem(),
-	GetBigqueryTableRegistryItem(),
-	GetCloudFunctionsRegistryItem(),
-	GetComputeAddressRegistryItem(),
+	getBigQueryDatasetRegistryItem(),
+	getBigQueryTableRegistryItem(),
+	getCloudFunctionsRegistryItem(),
+	getComputeAddressRegistryItem(),
 	GetComputeDiskRegistryItem(),
 	GetComputeExternalVPNGatewayRegistryItem(),
-	GetComputeForwardingRuleRegistryItem(),
+	getComputeForwardingRuleRegistryItem(),
 	GetComputeGlobalAddressRegistryItem(),
 	GetComputeGlobalForwardingRuleRegistryItem(),
 	GetComputeHAVPNGatewayRegistryItem(),
@@ -19,35 +19,35 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetComputeInstanceRegistryItem(),
 	GetComputeMachineImageRegistryItem(),
 	GetComputeRegionInstanceGroupManagerRegistryItem(),
-	GetComputeRegionTargetHTTPProxyRegistryItem(),
-	GetComputeRegionTargetHTTPSProxyRegistryItem(),
-	GetComputeRouterNATRegistryItem(),
+	getComputeRegionTargetHTTPProxyRegistryItem(),
+	getComputeRegionTargetHTTPSProxyRegistryItem(),
+	getComputeRouterNATRegistryItem(),
 	GetComputeSnapshotRegistryItem(),
-	GetComputeTargetGrpcProxyRegistryItem(),
-	GetComputeTargetHTTPProxyRegistryItem(),
-	GetComputeTargetHTTPSProxyRegistryItem(),
-	GetComputeTargetSslProxyRegistryItem(),
-	GetComputeTargetTCPProxyRegistryItem(),
+	getComputeTargetGRPCProxyRegistryItem(),
+	getComputeTargetHTTPProxyRegistryItem(),
+	getComputeTargetHTTPSProxyRegistryItem(),
+	getComputeTargetSSLProxyRegistryItem(),
+	getComputeTargetTCPProxyRegistryItem(),
 	GetComputeVPNGatewayRegistryItem(),
-	GetComputeVPNTunnelRegistryItem(),
+	getComputeVPNTunnelRegistryItem(),
 	GetContainerClusterRegistryItem(),
 	GetContainerNodePoolRegistryItem(),
 	GetContainerRegistryItem(),
-	GetDNSManagedZoneRegistryItem(),
-	GetDNSRecordSetRegistryItem(),
-	GetKMSCryptoKeyRegistryItem(),
-	GetLoggingBillingAccountBucketConfigRegistryItem(),
-	GetLoggingBillingAccountSinkRegistryItem(),
-	GetLoggingBucketConfigRegistryItem(),
-	GetLoggingFolderBucketConfigRegistryItem(),
-	GetLoggingFolderSinkRegistryItem(),
-	GetLoggingOrganizationBucketConfigRegistryItem(),
-	GetLoggingOrganizationSinkRegistryItem(),
-	GetLoggingProjectSinkRegistryItem(),
-	GetMonitoringItem(),
-	GetPubSubSubscriptionRegistryItem(),
-	GetPubSubTopicRegistryItem(),
-	GetRedisInstanceRegistryItem(),
+	getDNSManagedZoneRegistryItem(),
+	getDNSRecordSetRegistryItem(),
+	getKMSCryptoKeyRegistryItem(),
+	getLoggingBillingAccountBucketConfigRegistryItem(),
+	getLoggingBillingAccountSinkRegistryItem(),
+	getLoggingBucketConfigRegistryItem(),
+	getLoggingFolderBucketConfigRegistryItem(),
+	getLoggingFolderSinkRegistryItem(),
+	getLoggingOrganizationBucketConfigRegistryItem(),
+	getLoggingOrganizationSinkRegistryItem(),
+	getLoggingProjectSinkRegistryItem(),
+	getMonitoringItem(),
+	getPubSubSubscriptionRegistryItem(),
+	getPubSubTopicRegistryItem(),
+	getRedisInstanceRegistryItem(),
 	getSecretManagerSecretRegistryItem(),
 	getSecretManagerSecretVersionRegistryItem(),
 	GetSQLInstanceRegistryItem(),
